#
# spec file for package python-azure-mgmt-batch
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-azure-mgmt-batch
Version:        17.3.0
Release:        150400.14.6.2
Summary:        Microsoft Azure Batch Management Client Library
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/Azure/azure-sdk-for-python
Source:         https://files.pythonhosted.org/packages/source/a/azure-mgmt-batch/azure-mgmt-batch-%{version}.tar.gz
Source1:        LICENSE.txt
BuildRequires:  %{python_module azure-mgmt-nspkg >= 3.0.0}
BuildRequires:  %{python_module azure-nspkg >= 3.0.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-azure-mgmt-nspkg >= 3.0.0
Requires:       python-azure-nspkg >= 3.0.0
Requires:       (python-azure-common >= 1.1 with python-azure-common < 2.0.0)
Requires:       (python-azure-mgmt-core >= 1.3.2 with python-azure-mgmt-core < 2.0.0)
Requires:       (python-isodate >= 0.6.1 with python-isodate < 1.0.0)
Requires:       (python-typing_extensions >= 4.3.0 if python-base < 3.8)
Conflicts:      python-azure-sdk <= 2.0.0
%if 0%{?sle_version} >= 150400
Obsoletes:      python3-azure-mgmt-batch < 17.2.0
%endif
BuildArch:      noarch

%python_subpackages

%description
This is the Microsoft Azure Batch Management Client Library.

Azure Resource Manager (ARM) is the next generation of management APIs that
replace the old Azure Service Management (ASM).

This package has been tested with Python 2.7, 3.4, 3.5, 3.6 and 3.7.

%prep
%setup -q -n azure-mgmt-batch-%{version}

%build
install -m 644 %{SOURCE1} %{_builddir}/azure-mgmt-batch-%{version}
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%{python_expand # delete common files
rm -rf %{buildroot}%{$python_sitelib}/azure/mgmt/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/azure/mgmt/__pycache__
rm -rf %{buildroot}%{$python_sitelib}/azure/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/azure/__pycache__
}

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE.txt
%{python_sitelib}/azure/mgmt/batch
%{python_sitelib}/azure_mgmt_batch-*.dist-info

%changelog
* Tue Apr  9 2024 adrian.glaubitz@suse.com
- New upstream release
  + Version 17.3.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Thu Apr  4 2024 adrian.glaubitz@suse.com
- Switch package to modern Python Stack on SLE-15
  + Use Python 3.11 on SLE-15 by default
  + Add Obsoletes for old python3 package on SLE-15
  + Drop support for older Python versions
- Switch build system from setuptools to pyproject.toml
  + Add python-pip and python-wheel to BuildRequires
  + Replace %%python_build with %%pyproject_wheel
  + Replace %%python_install with %%pyproject_install
  + Update name for dist directory in %%files section
- Drop setting default file attributes in %%files section
* Tue Jan  2 2024 adrian.glaubitz@suse.com
- New upstream release
  + Version 17.2.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Remove unzip package from BuildRequires
- Switch source archive format to TAR.GZ
* Thu Jul 27 2023 dmueller@suse.com
- use proper boolean requires for ranged requirements
* Mon Jul 24 2023 adrian.glaubitz@suse.com
- New upstream release
  + Version 17.1.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Thu Nov 24 2022 adrian.glaubitz@suse.com
- New upstream release
  + Version 17.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Tue Jun  7 2022 adrian.glaubitz@suse.com
- New upstream release
  + Version 16.2.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Fri Feb 25 2022 adrian.glaubitz@suse.com
- New upstream release
  + Version 16.1.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Thu Aug  5 2021 adrian.glaubitz@suse.com
- New upstream release
  + Version 16.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Thu Mar 18 2021 adrian.glaubitz@suse.com
- New upstream release
  + Version 15.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Mon Jan 11 2021 adrian.glaubitz@suse.com
- New upstream release
  + Version 14.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Thu Nov 26 2020 rjschwei@suse.com
- Only build Python3 flavors for distributions 15 and greater
* Fri Jul 17 2020 adrian.glaubitz@suse.com
- New upstream release
  + Version 9.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Wed May  6 2020 adrian.glaubitz@suse.com
- New upstream release
  + Version 8.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Rename HISTORY.rst to CHANGELOG.md in %%files section
- Rename README.rst to README.md in %%files section
* Fri Oct  4 2019 adrian.glaubitz@suse.com
- New upstream release
  + Version 7.0.0
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
- Drop patches to support older versions of setuptools as
  SLE-12 is now shipping with a recent enough version
  + amb_drop-compatible-releases-operator.patch
  + amb_drop-extras-require.patch
- Remove python-devel package from BuildRequires
* Thu Apr 11 2019 adrian.glaubitz@suse.com
- New upstream release
  + Version 6.0.0
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
- Add patch to drop extras_require field from setup.py,
  required for SLES12 as the setuptools version is too old
  + amb_drop-extras-require.patch
- Bump minimum version for namespace packages
  to 3.0.0 in BuildRequires and Requires
- Remove python-devel package from BuildRequires
- Refresh patches for new version
  + amb_drop-compatible-releases-operator.patch
- Run fdupes to hardlink duplicate files
  + Add fdupes to BuildRequires
  + Add %%fdupes invocation to %%install
- Update %%description from setup.py
- Update BuildRequires and Requires from setup.py
* Mon Sep  3 2018 adrian.glaubitz@suse.com
- New upstream release
  + Version 5.0.1
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
- Move LICENSE.txt from %%doc to %%license section
- Refresh patches for new version
  + amb_drop-compatible-releases-operator.patch
- Update Requires from setup.py
* Thu Jan 18 2018 adrian.glaubitz@suse.com
- New upstream release
  + Version 5.0.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Install HISTORY.rst into doc directory
- Refresh patches for new version
  + amb_drop-compatible-releases-operator.patch
- Update Requires from setup.py
* Wed Oct  4 2017 adrian.glaubitz@suse.com
- Remove versioning for namespace packages in Requires
- Add namespace packages to BuildRequires
- Remove namespace files in %%install target
- Explicitly specify Python files of the package in %%files
* Thu Sep 14 2017 adrian.glaubitz@suse.com
- New upstream release
  + Version 4.1.0
* Thu Jul 13 2017 adrian.glaubitz@suse.com
- Add python-azure-nspkg to Requires
- Add python-azure-mgmt-nspkg to Requires
* Tue Jun 27 2017 adrian.glaubitz@suse.com
- Initial build
  + Version 4.0.0
- Add patch to drop compatible releases operator from setup.py,
  required for SLES12 as the setuptools version is too old
  + amb_drop-compatible-releases-operator.patch
